	 function [G, Z, P] = BESSEL_POLES(Tg0, N)
	 % 
	 %	Computes the zeros, poles, and gain constant for a Bessel filter 
	 %	with the group delay at w = 0 is Tg0
	 %
	 %	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
	 
	 % 	Author: 		Lars Wanhammar, 2008-11-14
	 % 	Modified by: 	LW 2010-06-12	
	 % 	Copyright:		Divison of Electronics Systems
	 % 					Dept. Electrical Engineering, Linkoping University, Sweden
	 % 	Version: 		1
	 % 	Known bugs:		None
	 % 	Report bugs to:	larsw@isy.liu.se
	 %
	 
	 % N must be an integer
	 if ~(abs(N-round(N)) < eps)
		 error('N must be an integeer')  
	 end
	 
	 Den = zeros(0,N+1);
	 for n = 0:N
		 Den(n+1) = prod(1:2*N-n)/(prod(1:n)*prod(1:N-n)*2^(N-n));
	 end
	 Den = fliplr(Den);
	 P = roots(Den)/Tg0;;
	 G = prod(P);
	 Z = [];
