	function [G, Z, P] = BW_POLES(Wc, Ws, Amax, Amin, N)
	%
	% 	Computes the denormalized poles, zeros, and gain constant for  
	%	an analog lowpass Butterworth filter with |H(0)| = 1.
	%	The design margin is used to decreae the stopband edge.
	%
	% 	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
	
	% 	Author: 		Lars Wanhammar 1986-9-27
	% 	Modified by: 	LW 2000-10-31, 2002-07-28, 2004-09-22
	% 	Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1
	% 	Known bugs:		None
	% 	Report bugs to:	larsw@isy.liu.se
	%
	if ~(abs(N-round(N)) < eps)
		N = floor(BW_ORDER(Wc, Ws, Amax, Amin)) + 1;
	end
	if (Wc >= Ws)
		error('Not a lowpass filter. Must have Wc < Ws')  
	elseif ( Amax <= 0 | Amax >= Amin)
		error('The passband attenuation must be 0 < Amax < Amin')
	elseif ( Amin <= 0)
		error('The stopband attenuation must be Amin > Amax > 0')
	end 
	Z = [];
	P = [];
	Apn = Amax*log(10)/20;
	epsilon = sqrt(2*exp(Apn)*sinh(Apn));
	rp0 = Wc*epsilon^(-1/N);
	odd = rem(N, 2);
	if odd == 1
		M = (N+1)/2; 
	else
		M = N/2;
	end
	for k = 1:M
		X = rp0*exp(i*(N-1+2*k)*pi/(2*N));
		if ~(odd == 1 & k == M)
			P = [conj(X); X; P];
		else
			P = [X; P];
		end
	end
	G = rp0^N;	% Gain constant
