	function [G, Z, P, Wsnew] = CH_I_C_POLES(G, Z, P, Wc, Ws)
	%
	% Transforms the poles of an even order analog lowpass filter of
	% Chebyshev I type A with cutoff frequency Wc to have A(0) = 0. 
	% That is into a Chevbshev I filter type C.
	% The cutoff edge is invariant, only the stoband edge, Ws, is increased.
	%
	% Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
		
	% Author: 			Lars Wanhammar, 2008-07-15
	% Modified by: 		 
	% Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% Version: 			1
	% Known bugs:		None
	% Report bugs to:	larsw@isy.liu.se
	%
	
	N = length (P);
	W0 = Wc*sin(pi/(2*N));	% Lowest reflection zero
	% Transform the poles
	for n = 1:length(P)
		 P(n) = -sqrt(P(n)^2+W0^2)/cos(pi/(2*N));
	 end
	G = real(prod(P));	% Gain constant
	
	% The new stopband edge is
	Wsnew = imag(sqrt((Wc*sin(pi/(2*N)))^2 - Ws^2)/cos(pi/(2*N)));
